@@ -151,13 +151,14 @@ int feh_load_image(Imlib_Image * im, feh_file * file)
 			/* Http, no reload, slideshow. Let's keep this image on hand... */
 			free(file->filename);
 			file->filename = estrdup(tmpname);
+
+			if (!opt.keep_http)
+				add_file_to_rm_filelist(tmpname);
 		} else {
 			/* Don't cache the image if we're doing reload + http (webcams etc) */
 			if (!opt.keep_http)
 				unlink(tmpname);
 		}
-		if (!opt.keep_http)
-			add_file_to_rm_filelist(tmpname);
 		free(tmpname);
 	} else {
 		*im = imlib_load_image_with_error_return(file->filename, &err);
@@ -168,65 +169,52 @@ int feh_load_image(Imlib_Image * im, feh_file * file)
 			fputs("\n", stdout);
 			reset_output = 1;
 		}
-		/* Check error code */
-		switch (err) {
-		case IMLIB_LOAD_ERROR_FILE_DOES_NOT_EXIST:
-			if (!opt.quiet)
-				weprintf("%s - File does not exist", file->filename);
-			break;
-		case IMLIB_LOAD_ERROR_FILE_IS_DIRECTORY:
-			if (!opt.quiet)
-				weprintf("%s - Directory specified for image filename", file->filename);
-			break;
-		case IMLIB_LOAD_ERROR_PERMISSION_DENIED_TO_READ:
-			if (!opt.quiet)
-				weprintf("%s - No read access to directory", file->filename);
-			break;
-		case IMLIB_LOAD_ERROR_UNKNOWN:
-		case IMLIB_LOAD_ERROR_NO_LOADER_FOR_FILE_FORMAT:
-			if (!opt.quiet)
-				weprintf("%s - No Imlib2 loader for that file format", file->filename);
-			break;
-		case IMLIB_LOAD_ERROR_PATH_TOO_LONG:
-			if (!opt.quiet)
-				weprintf("%s - Path specified is too long", file->filename);
-			break;
-		case IMLIB_LOAD_ERROR_PATH_COMPONENT_NON_EXISTANT:
-			if (!opt.quiet)
-				weprintf("%s - Path component does not exist", file->filename);
-			break;
-		case IMLIB_LOAD_ERROR_PATH_COMPONENT_NOT_DIRECTORY:
-			if (!opt.quiet)
-				weprintf("%s - Path component is not a directory", file->filename);
-			break;
-		case IMLIB_LOAD_ERROR_PATH_POINTS_OUTSIDE_ADDRESS_SPACE:
-			if (!opt.quiet)
-				weprintf("%s - Path points outside address space", file->filename);
-			break;
-		case IMLIB_LOAD_ERROR_TOO_MANY_SYMBOLIC_LINKS:
-			if (!opt.quiet)
-				weprintf("%s - Too many levels of symbolic links", file->filename);
-			break;
-		case IMLIB_LOAD_ERROR_OUT_OF_MEMORY:
-			if (!opt.quiet)
-				weprintf("While loading %s - Out of memory", file->filename);
-			break;
-		case IMLIB_LOAD_ERROR_OUT_OF_FILE_DESCRIPTORS:
+		if (err == IMLIB_LOAD_ERROR_OUT_OF_FILE_DESCRIPTORS)
 			eprintf("While loading %s - Out of file descriptors", file->filename);
-			break;
-		case IMLIB_LOAD_ERROR_PERMISSION_DENIED_TO_WRITE:
-			if (!opt.quiet)
+		else if (!opt.quiet) {
+			switch (err) {
+			case IMLIB_LOAD_ERROR_FILE_DOES_NOT_EXIST:
+				weprintf("%s - File does not exist", file->filename);
+				break;
+			case IMLIB_LOAD_ERROR_FILE_IS_DIRECTORY:
+				weprintf("%s - Directory specified for image filename", file->filename);
+				break;
+			case IMLIB_LOAD_ERROR_PERMISSION_DENIED_TO_READ:
+				weprintf("%s - No read access to directory", file->filename);
+				break;
+			case IMLIB_LOAD_ERROR_UNKNOWN:
+			case IMLIB_LOAD_ERROR_NO_LOADER_FOR_FILE_FORMAT:
+				weprintf("%s - No Imlib2 loader for that file format", file->filename);
+				break;
+			case IMLIB_LOAD_ERROR_PATH_TOO_LONG:
+				weprintf("%s - Path specified is too long", file->filename);
+				break;
+			case IMLIB_LOAD_ERROR_PATH_COMPONENT_NON_EXISTANT:
+				weprintf("%s - Path component does not exist", file->filename);
+				break;
+			case IMLIB_LOAD_ERROR_PATH_COMPONENT_NOT_DIRECTORY:
+				weprintf("%s - Path component is not a directory", file->filename);
+				break;
+			case IMLIB_LOAD_ERROR_PATH_POINTS_OUTSIDE_ADDRESS_SPACE:
+				weprintf("%s - Path points outside address space", file->filename);
+				break;
+			case IMLIB_LOAD_ERROR_TOO_MANY_SYMBOLIC_LINKS:
+				weprintf("%s - Too many levels of symbolic links", file->filename);
+				break;
+			case IMLIB_LOAD_ERROR_OUT_OF_MEMORY:
+				weprintf("While loading %s - Out of memory", file->filename);
+				break;
+			case IMLIB_LOAD_ERROR_PERMISSION_DENIED_TO_WRITE:
 				weprintf("%s - Cannot write to directory", file->filename);
-			break;
-		case IMLIB_LOAD_ERROR_OUT_OF_DISK_SPACE:
-			if (!opt.quiet)
+				break;
+			case IMLIB_LOAD_ERROR_OUT_OF_DISK_SPACE:
 				weprintf("%s - Cannot write - out of disk space", file->filename);
-			break;
-		default:
-			if (!opt.quiet)
-				weprintf("While loading %s - Unknown error (%d). Attempting to continue",
+				break;
+			default:
+				weprintf("While loading %s - Unknown error (%d)",
 						file->filename, err);
-			break;
+				break;
+			}
 		}
 		D(("Load *failed*\n"));
 		return(0);
@@ -542,6 +530,9 @@ void feh_draw_info(winwidget w)
 		pclose(info_pipe);
 	}
 
+	if (no_lines == 0)
+		return;
+
 	height *= no_lines;
 	width += 4;
 
@@ -726,6 +717,13 @@ void feh_display_status(char stat)
 
 	D(("filelist %p, filelist->next %p\n", filelist, filelist->next));
 
+	if (!stat) {
+		putc('\n', stdout);
+		init_len = 0;
+		i = 0;
+		return;
+	}
+
 	if (!init_len)
 		init_len = gib_list_length(filelist);
 
