@@ -58,23 +58,9 @@ void init_parse_options(int argc, char **argv)
 	opt.thumb_redraw = 10;
 	opt.menu_font = estrdup(DEFAULT_MENU_FONT);
 	opt.font = NULL;
-	opt.image_bg = estrdup("default");
 	opt.menu_bg = estrdup(PREFIX "/share/feh/images/menubg_default.png");
 	opt.menu_style = estrdup(PREFIX "/share/feh/fonts/menu.style");
 
-	opt.reload_button = 0;
-	opt.pan_button = 1;
-	opt.zoom_button = 2;
-	opt.menu_button = 3;
-	opt.menu_ctrl_mask = 0;
-	opt.prev_button = 4;
-	opt.next_button = 5;
-
-	opt.rotate_button = 2;
-	opt.no_rotate_ctrl_mask = 0;
-	opt.blur_button = 1;
-	opt.no_blur_ctrl_mask = 0;
-
 	opt.start_list_at = NULL;
 	opt.jump_on_resort = 1;
 
@@ -104,9 +90,6 @@ void init_parse_options(int argc, char **argv)
 
 	D(("Options parsed\n"));
 
-	if (opt.bgmode)
-		return;
-
 	filelist_len = gib_list_length(filelist);
 	if (!filelist_len)
 		show_mini_usage();
@@ -319,7 +302,7 @@ static void feh_parse_option_array(int argc, char **argv, int finalrun)
 {
 	static char stropts[] =
 		"a:A:b:B:cC:dD:e:E:f:Fg:GhH:iIj:J:kK:lL:mM:nNo:O:pPqrR:sS:tT:uUvVwW:xXy:YzZ"
-		"0:1:2:4:5:8:9:.@:^:~:):|:+:";
+		".@:^:~:):|:+:";
 
 	/* (*name, has_arg, *flag, val) See: struct option in getopts.h */
 	static struct option lopts[] = {
@@ -356,9 +339,6 @@ static void feh_parse_option_array(int argc, char **argv, int finalrun)
 		{"cache-thumbnails", 0, 0, 'P'},
 		{"cycle-once"    , 0, 0, 224},
 		{"no-xinerama"   , 0, 0, 225},
-		{"no-rotate-ctrl-mask", 0, 0, 226},
-		{"no-blur-ctrl-mask", 0, 0, 227},
-		{"menu-ctrl-mask", 0, 0, 228},
 		{"draw-tinted"   , 0, 0, 229},
 
 		{"output"        , 1, 0, 'o'},
@@ -385,23 +365,16 @@ static void feh_parse_option_array(int argc, char **argv, int finalrun)
 		{"fontpath"      , 1, 0, 'C'},
 		{"menu-bg"       , 1, 0, ')'},
 		{"image-bg"      , 1, 0, 'B'},
-		{"reload-button" , 1, 0, '0'},
-		{"pan-button"    , 1, 0, '1'},
-		{"zoom-button"   , 1, 0, '2'},
-		{"menu-button"   , 1, 0, '3'},
-		{"prev-button"   , 1, 0, '4'},
-		{"next-button"   , 1, 0, '5'},
-		{"rotate-button" , 1, 0, '8'},
-		{"blur-button"   , 1, 0, '9'},
 		{"start-at"      , 1, 0, '|'},
 		{"debug"         , 0, 0, '+'},
 		{"output-dir"    , 1, 0, 'j'},
-		{"bg-tile"       , 1, 0, 200},
-		{"bg-center"     , 1, 0, 201},
-		{"bg-scale"      , 1, 0, 202},
+		{"bg-tile"       , 0, 0, 200},
+		{"bg-center"     , 0, 0, 201},
+		{"bg-scale"      , 0, 0, 202},
 		{"menu-style"    , 1, 0, 204},
 		{"zoom"          , 1, 0, 205},
 		{"no-screen-clip", 0, 0, 206},
+		{"index-info"    , 1, 0, 207},
 		{"caption-path"  , 1, 0, 'K'},
 		{"action1"       , 1, 0, 209},
 		{"action2"       , 1, 0, 210},
@@ -412,11 +385,8 @@ static void feh_parse_option_array(int argc, char **argv, int finalrun)
 		{"action7"       , 1, 0, 215},
 		{"action8"       , 1, 0, 216},
 		{"action9"       , 1, 0, 217},
-		{"bg-fill"       , 1, 0, 218},
-		{"bg-max"        , 1, 0, 219},
-		{"index-name"    , 1, 0, 230},
-		{"index-size"    , 1, 0, 231},
-		{"index-dim"     , 1, 0, 232},
+		{"bg-fill"       , 0, 0, 218},
+		{"bg-max"        , 0, 0, 219},
 		{"thumb-redraw"  , 1, 0, 'J'},
 		{"info"          , 1, 0, 234},
 		{"force-aliasing", 0, 0, 235},
@@ -439,27 +409,20 @@ static void feh_parse_option_array(int argc, char **argv, int finalrun)
 			break;
 		case 'm':
 			opt.index = 1;
-			opt.index_show_name = 0;
-			opt.index_show_size = 0;
-			opt.index_show_dim = 0;
 			break;
 		case 'c':
 			opt.collage = 1;
 			break;
 		case 'i':
 			opt.index = 1;
-			opt.index_show_name = 1;
-			opt.index_show_size = 0;
-			opt.index_show_dim = 0;
+			opt.index_info = estrdup("%n");
 			break;
 		case '.':
 			opt.scale_down = 1;
 			break;
 		case 'I':
 			opt.index = 1;
-			opt.index_show_name = 1;
-			opt.index_show_size = 1;
-			opt.index_show_dim = 1;
+			opt.index_info = estrdup("%n\n%S\n%wx%h");
 			break;
 		case 'l':
 			opt.list = 1;
@@ -606,8 +569,14 @@ static void feh_parse_option_array(int argc, char **argv, int finalrun)
 			weprintf("The --menu-bg option is deprecated and will be removed by 2012");
 			break;
 		case 'B':
-			free(opt.image_bg);
-			opt.image_bg = estrdup(optarg);
+			if (!strcmp(optarg, "checks"))
+				opt.image_bg = IMAGE_BG_CHECKS;
+			else if (!strcmp(optarg, "white"))
+				opt.image_bg = IMAGE_BG_WHITE;
+			else if (!strcmp(optarg, "black"))
+				opt.image_bg = IMAGE_BG_BLACK;
+			else
+				weprintf("Unknown argument to --image-bg: %s", optarg);
 			break;
 		case 'D':
 			opt.slideshow_delay = atof(optarg);
@@ -629,61 +598,30 @@ static void feh_parse_option_array(int argc, char **argv, int finalrun)
 			else
 				opt.filelistfile = estrdup(optarg);
 			break;
-		case '0':
-			opt.reload_button = atoi(optarg);
-			break;
-		case '1':
-			opt.pan_button = atoi(optarg);
-			break;
-		case '2':
-			opt.zoom_button = atoi(optarg);
-			break;
-		case '3':
-			opt.menu_button = atoi(optarg);
-			break;
-		case '4':
-			opt.prev_button = atoi(optarg);
-			break;
-		case '5':
-			opt.next_button = atoi(optarg);
-			break;
-		case '8':
-			opt.rotate_button = atoi(optarg);
-			break;
-		case '9':
-			opt.blur_button = atoi(optarg);
-			break;
 		case '|':
 			opt.start_list_at = estrdup(optarg);
 			break;
 		case 't':
 			opt.thumbs = 1;
-			opt.index_show_name = 1;
-			opt.index_show_size = 0;
-			opt.index_show_dim = 0;
+			opt.index_info = estrdup("%n");
 			break;
 		case 'j':
 			opt.output_dir = estrdup(optarg);
 			break;
 		case 200:
 			opt.bgmode = BG_MODE_TILE;
-			opt.output_file = estrdup(optarg);
 			break;
 		case 201:
 			opt.bgmode = BG_MODE_CENTER;
-			opt.output_file = estrdup(optarg);
 			break;
 		case 202:
 			opt.bgmode = BG_MODE_SCALE;
-			opt.output_file = estrdup(optarg);
 			break;
 		case 218:
 			opt.bgmode = BG_MODE_FILL;
-			opt.output_file = estrdup(optarg);
 			break;
 		case 219:
 			opt.bgmode = BG_MODE_MAX;
-			opt.output_file = estrdup(optarg);
 			break;
 		case 204:
 			free(opt.menu_style);
@@ -701,6 +639,9 @@ static void feh_parse_option_array(int argc, char **argv, int finalrun)
 		case 206:
 			opt.screen_clip = 0;
 			break;
+		case 207:
+			opt.index_info = estrdup(optarg);
+			break;
 		case 'K':
 			opt.caption_path = estrdup(optarg);
 			break;
@@ -749,27 +690,9 @@ static void feh_parse_option_array(int argc, char **argv, int finalrun)
 		case 225:
 			opt.xinerama = 0;
 			break;
-		case 226:
-			opt.no_rotate_ctrl_mask = 1;
-			break;
-		case 227:
-			opt.no_blur_ctrl_mask = 1;
-			break;
-		case 228:
-			opt.menu_ctrl_mask = 1;
-			break;
 		case 229:
 			opt.text_bg = TEXT_BG_TINTED;
 			break;
-		case 230:
-			opt.index_show_name = atoi(optarg);
-			break;
-		case 231:
-			opt.index_show_size = atoi(optarg);
-			break;
-		case 232:
-			opt.index_show_dim = atoi(optarg);
-			break;
 		case 'J':
 			opt.thumb_redraw = atoi(optarg);
 			break;
@@ -820,7 +743,7 @@ static void check_options(void)
 	}
 
 	if (opt.full_screen && opt.multiwindow) {
-		eprintf("You cannot combine --full-screen with --multiwindow");
+		eprintf("You cannot combine --fullscreen with --multiwindow");
 	}
 
 	if (opt.list && (opt.multiwindow || opt.index || opt.collage)) {
@@ -837,13 +760,6 @@ static void check_options(void)
 		eprintf("You cannot combine --loadable with --unloadable");
 	}
 
-	if (opt.thumb_title && (!opt.thumbs)) {
-		weprintf("Doesn't make sense to set thumbnail title when not in\n"
-				"thumbnail mode.\n");
-		free(opt.thumb_title);
-		opt.thumb_title = NULL;
-	}
-
 	return;
 }
 
@@ -860,6 +776,10 @@ static void show_version(void)
 		"debug "
 #endif
 
+#if _FILE_OFFSET_BITS == 64
+		"stat64 "
+#endif
+
 #ifdef HAVE_LIBXINERAMA
 		"xinerama "
 #endif
