@@ -27,17 +27,11 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #ifndef OPTIONS_H
 #define OPTIONS_H
 
-#define ZOOM_MODE_FILL 1
-#define ZOOM_MODE_MAX  2
-
 struct __fehoptions {
 	unsigned char multiwindow;
 	unsigned char montage;
 	unsigned char collage;
 	unsigned char index;
-	unsigned char index_show_name;
-	unsigned char index_show_dim;
-	unsigned char index_show_size;
 	unsigned char thumbs;
 	unsigned char slideshow;
 	unsigned char recursive;
@@ -72,6 +66,8 @@ struct __fehoptions {
 	unsigned char cache_thumbnails;
 	unsigned char cycle_once;
 	unsigned char hold_actions[10];
+	unsigned char text_bg;
+	unsigned char image_bg;
 
 	char *output_file;
 	char *output_dir;
@@ -86,28 +82,14 @@ struct __fehoptions {
 	char *menu_font;
 	char *customlist;
 	char *menu_bg;
-	char *image_bg;
 	char *menu_style;
 	char *caption_path;
 	char *start_list_at;
 	char *info_cmd;
+	char *index_info;
 
 	gib_style *menu_style_l;
 
-	unsigned char pan_button;
-	unsigned char zoom_button;
-	unsigned char menu_button;
-	unsigned char menu_ctrl_mask;
-	unsigned char prev_button;
-	unsigned char next_button;
-
-	unsigned char rotate_button;
-	unsigned char blur_button;
-	unsigned char reload_button;
-	unsigned char no_rotate_ctrl_mask;
-	unsigned char no_blur_ctrl_mask;
-	unsigned char no_pan_ctrl_mask;
-
 	int force_aliasing;
 	int thumb_w;
 	int thumb_h;
@@ -152,6 +134,10 @@ struct __fehkb {
 	struct __fehkey next_img;
 	struct __fehkey scroll_up;
 	struct __fehkey scroll_down;
+	struct __fehkey scroll_right_page;
+	struct __fehkey scroll_left_page;
+	struct __fehkey scroll_up_page;
+	struct __fehkey scroll_down_page;
 	struct __fehkey jump_back;
 	struct __fehkey quit;
 	struct __fehkey jump_fwd;
@@ -190,11 +176,29 @@ struct __fehkb {
 	struct __fehkey close;
 	struct __fehkey orient_1;
 	struct __fehkey orient_3;
+	struct __fehkey flip;
+	struct __fehkey mirror;
 	struct __fehkey toggle_fullscreen;
 	struct __fehkey reload_minus;
 	struct __fehkey reload_plus;
 };
 
+struct __fehbutton {
+	int modifier;
+	char button;
+};
+
+struct __fehbb {
+	struct __fehbutton pan;
+	struct __fehbutton zoom;
+	struct __fehbutton reload;
+	struct __fehbutton prev;
+	struct __fehbutton next;
+	struct __fehbutton menu;
+	struct __fehbutton blur;
+	struct __fehbutton rotate;
+};
+
 void init_parse_options(int argc, char **argv);
 char *feh_string_normalize(char *str);
 
